@@ -15,7 +15,6 @@ test_that("SI, 1G, CL: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -40,7 +39,6 @@ test_that("SI, 1G, CL: 2 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -53,10 +51,10 @@ test_that("SI, 1G, CL: 2 sim", {
   test_icm(x)
 })
 
-test_that("SI, 1G, CL: inf.prob = 0, status.rand = FALSE", {
+test_that("SI, 1G, CL: inf.prob = 0", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0, act.rate = 0.25)
-  init <- init.icm(s.num = 500, i.num = 1, status.rand = FALSE)
+  init <- init.icm(s.num = 500, i.num = 1)
   control <- control.icm(type = "SI", nsteps = 25, nsims = 10, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
@@ -90,7 +88,6 @@ test_that("SI, 2G, CL: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -138,7 +135,6 @@ test_that("SI, 1G, OP: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -188,7 +184,6 @@ test_that("SI, 2G, OP: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -242,7 +237,6 @@ test_that("SIR, 1G, CL: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -277,10 +271,10 @@ test_that("SIR, 1G, CL: 2 sim", {
   test_icm(x)
 })
 
-test_that("SIR, 1G, CL: inf.prob = 0, status.rand = FALSE", {
+test_that("SIR, 1G, CL: inf.prob = 0", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0, act.rate = 0.25, rec.rate = 0)
-  init <- init.icm(s.num = 500, i.num = 1, r.num = 0, status.rand = FALSE)
+  init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
   control <- control.icm(type = "SIR", nsteps = 10, nsims = 10, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
@@ -315,7 +309,6 @@ test_that("SIR, 2G, CL: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -364,7 +357,6 @@ test_that("SIR, 1G, OP: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -419,7 +411,6 @@ test_that("SIR, 2G, OP: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -475,7 +466,6 @@ test_that("SIS, 1G, CL: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -511,10 +501,10 @@ test_that("SIS, 1G, CL: 2 sim", {
   test_icm(x)
 })
 
-test_that("SIS, 1G, CL: inf.prob = 0, status.rand = FALSE", {
+test_that("SIS, 1G, CL: inf.prob = 0", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0, act.rate = 0.25, rec.rate = 0)
-  init <- init.icm(s.num = 500, i.num = 1, status.rand = FALSE)
+  init <- init.icm(s.num = 500, i.num = 1)
   control <- control.icm(type = "SIS", nsteps = 10, nsims = 10, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
@@ -546,7 +536,6 @@ test_that("SIS, 2G, CL: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -592,7 +581,6 @@ test_that("SIS, 1G, OP: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -642,7 +630,6 @@ test_that("SIS, 2G, OP: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
